@@ -375,9 +375,15 @@ class OpenSSHTransport(Transport):
         if self.host.ssh_key_filename:
             key_filename = os.path.expanduser(self.host.ssh_key_filename)
             argv.extend(['-i', key_filename])
+            # disable password prompt
+            argv.extend(['-o', 'BatchMode=yes'])
         elif self.host.ssh_password:
-            self.log.critical('Password authentication not supported')
-            raise RuntimeError('Password authentication not supported')
+            password_file = os.path.join(self.control_dir.path, 'password')
+            with open(password_file, 'w') as f:
+                os.fchmod(f.fileno(), 600)
+                f.write(self.host.ssh_password)
+                f.write('\n')
+            argv = ['sshpass', '-f', password_file] + argv
         else:
             self.log.critical('No SSH credentials configured')
             raise RuntimeError('No SSH credentials configured')
